# This is a version of BCEL that has been modified by the findbugs team.  They
# added some new functionality and also did some performance optimizations of
# the base code.  I am not producing a new manual, since we already have a
# bcel-manual package and the findbugs team did not patch the manual.  However,
# the javadoc package is necessary to show the changes in the API created by
# the findbug team's work.

%global findbugsver 1.3.8

Name:           findbugs-bcel
Version:        5.2
Release:        %mkrel 0.%{findbugsver}.7
Summary:        Byte Code Engineering Library with findbugs extensions

Group:          Development/Java
License:        ASL 2.0
URL:            http://jakarta.apache.org/bcel/
Source0:        http://www.apache.org/dist/jakarta/bcel/source/bcel-%{version}-src.tar.gz
# This patch is available in the findbugs release, in src/patches/bcel.diff.
Source1:        bcel.diff
#Source2:       http://findbugs.googlecode.com/svn/repos/release-repository/com/google/code/findbugs/bcel/1.3.9/bcel-1.3.9.pom
Source2:        http://repo1.maven.org/maven2/net/sourceforge/findbugs/bcel/1.3.7/bcel-1.3.7.pom

BuildRequires:  java-devel, jpackage-utils
Requires:       java, jpackage-utils

BuildArch:      noarch

%description
This is a version of Apache's Byte Code Engineering Library (BCEL) that has
been modified by the findbugs developers.  The modifications add some new
functionality, and also introduce a number of performance optimizations to
address findbugs performance problems.  Some of the performance optimizations
induce API changes, so this version of BCEL is not compatible with the vanilla
upstream version.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%prep
%setup -q -n bcel-%{version}
%{__patch} -p7 -s < %{SOURCE1}

cp -p %{SOURCE2} pom.xml
sed -i "s|1.3.7|1.3.9|" pom.xml


%build
# The ant and maven builds both try to download unneeded jars
mkdir classes
find src/java -type f -name '*.java' | \
xargs javac -g -d classes -source 1.5 -encoding ISO8859-1
cd classes
jar cf findbugs-bcel-%{findbugsver}.jar org
cd ..

mkdir javadoc
find src/java -type f -name '*.java' | xargs javadoc -sourcepath src/java \
  -classpath classes -source 1.5 -encoding ISO8859-1 -d javadoc 

%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p classes/%{name}-%{findbugsver}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar

# Install poms
mkdir -p $RPM_BUILD_ROOT%{_mavenpomdir}
cp pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom

# Add depmaps
# WARNING when use google pom change -a "com.google.code.findbugs:bcel" with -a "net.sourceforge.findbugs:bcel"
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a "com.google.code.findbugs:bcel"

mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%name
cp -a javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%pre javadoc
# workaround for rpm bug, can be removed in F-17
[ $1 -gt 1 ] && [ -L %{_javadocdir}/%{name} ] && \
rm -rf $(readlink -f %{_javadocdir}/%{name}) %{_javadocdir}/%{name} || :

%files
%doc LICENSE.txt NOTICE.txt README.txt
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%doc LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}


%changelog

* Sat Jan 12 2013 dmorgan <dmorgan> 5.2-0.1.3.8.7.mga3
+ Revision: 352481
- Clean spec file

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 21 2011 dmorgan <dmorgan> 1.3.9-1.mga2
+ Revision: 157165
- Fix group

  + gil <gil>
    - added new maven2 poms

* Mon Jun 27 2011 gil <gil> 1.3.9-0.mga2
+ Revision: 114814
- imported package findbugs-bcel


* Mon Jun 27 2011 gil <gil> 1.3.9-0.%%mkrel
- initial rpm